@@ -110,7 +110,7 @@ def get_outliers_inliers(X, y):
 
 
 def generate_data(n_train=1000, n_test=500, n_features=2, contamination=0.1,
-                  train_only=False, offset=10, behaviour='old',
+                  train_only=False, offset=10, behaviour='new',
                   random_state=None, n_nan=0, n_inf=0):
     """Utility function to generate synthesized data.
     Normal data is generated by a multivariate Gaussian distribution and
@@ -139,21 +139,12 @@ def generate_data(n_train=1000, n_test=500, n_features=2, contamination=0.1,
     offset : int, optional (default=10)
         Adjust the value range of Gaussian and Uniform.
 
-    behaviour : str, default='old'
+    behaviour : str, default='new'
         Behaviour of the returned datasets which can be either 'old' or
         'new'. Passing ``behaviour='new'`` returns
         "X_train, X_test, y_train, y_test", while passing ``behaviour='old'``
         returns "X_train, y_train, X_test, y_test".
 
-        .. versionadded:: 0.7.0
-           ``behaviour`` is added in 0.7.0 for back-compatibility purpose.
-        .. deprecated:: 0.7.0
-           ``behaviour='old'`` is deprecated in 0.20 and will not be possible
-           in 0.7.2.
-        .. deprecated:: 0.7.2.
-           ``behaviour`` parameter will be deprecated in 0.7.2 and removed in
-           0.9.0.
-
     random_state : int, RandomState instance or None, optional (default=None)
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
